@@ -1,3 +1,4 @@
+#todo (whole file): remove self-reference
 .mecdf.step = function (u)
 {	k = rep (TRUE, .$nr)
 	for (j in 1:.$nc) k = k & (.$x [,j] <= u [j])
@@ -10,13 +11,15 @@
 	(sum (k) - 1) / (.$nr - 1)
 }
 
+#todo: simplify...
+#todo: remove interpolation over vertices with same values
 .mecdf.continuous = function (u)
 {	k = rep (NA, .$nc)
 	a = b = p = q = numeric (.$nc)
 	for (j in 1:.$nc)
 	{	i = (.$x [,j] <= u [j])
 		n1 = sum (i)
-		if (n1 == 0) k [j] = 0
+		if (n1 == 0) k [j] = -Inf
 		else if (n1 == .$nr) k [j] = max (.$x [,j])
 		else
 		{	x1 = .$x [i, j]
@@ -28,7 +31,7 @@
 			}
 		}
 	}
-	if (any (!is.na (k) & k == 0) ) 0
+	if (any (!is.na (k) & k == -Inf) ) 0
 	else if (all (!is.na (k) ) ) .$Fst (k)
 	else
 	{	p = (u - a) / (b - a)
@@ -51,3 +54,20 @@
 	}
 }
 
+#assume sorted
+.mecdf.step.univariate = function (u)
+	sum (x <= u) / nr
+
+#assume sorted
+.mecdf.continuous.univariate = function (u)
+{	k = sum (x <= u)
+	a = (k - 1) / (nr - 1)
+	b = k / (nr - 1)
+	if (u == x [k]) a
+	else
+	{	p = (u - x [k]) / (x [k + 1] - x [k])
+		q = 1 - p
+		q * a + p * b
+	}
+}
+
